@@ -7,8 +7,8 @@ function(..., append.model=TRUE, nl.obj=NULL)
     nl.obj <- "_nl.intern_"
   }
   # get NetLogo reference
-  if (nl.obj %in% names(.rnetlogo$objects)) {
-    nl.obj <- .rnetlogo$objects[[nl.obj]]
+  if (nl.obj %in% .rnetlogo$objects) {
+	nl.obj <- get(nl.obj, envir=.rnetlogo)
   } else {
     stop(paste('There is no NetLogo reference stored under the name ',nl.obj,".", sep=""))
   } 
